@@ -1,6 +1,5 @@
 #' Relative survival, AER and SMR based on French death rates
 #' @title Relative survival, AER and SMR based on French death rates
 #' @author Jean-Philippe Jais and Hugo Varet
-#' @docType package
 #' @name survexp.fr-package
-NULL
+"_PACKAGE"
